/*
 * This file is part of the xTuple ERP: PostBooks Edition, a free and
 * open source Enterprise Resource Planning software suite,
 * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
 * It is licensed to you under the Common Public Attribution License
 * version 1.0, the full text of which (including xTuple-specific Exhibits)
 * is available at www.xtuple.com/CPAL.  By using this software, you agree
 * to be bound by its terms.
 */

#ifndef CREATEINVOICES_H
#define CREATEINVOICES_H

#include "guiclient.h"
#include "xdialog.h"
#include "ui_createInvoices.h"

class createInvoices : public XDialog, public Ui::createInvoices
{
    Q_OBJECT

public:
    createInvoices(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
    ~createInvoices();

public slots:
    virtual void sPost();

protected slots:
    virtual void languageChange();

};

#endif // CREATEINVOICES_H
